import shapefile

sf = shapefile.Reader("pyshp/shapefiles/blockgroups")

print sf.shapeType

shapes = sf.shapes()

print len(shapes)

s = sf.shape(7)
print ['%.3f' % coord for coord in s.bbox]

for name in dir(shapes[3]):
    if not name.startswith('_'):
        print name


fields = sf.fields
print fields

shapeRecs = sf.shapeRecords()

print len(shapeRecs)

print shapeRecs[0].record[1:3]
print shapeRecs[0].shape.points[0:2]



#-*- coding: utf-8 -*-
import shapefile
import json

path = "pyshp/shapefiles/blockgroups"
sf = shapefile.Reader(path)

fields = sf.fields[1:]
field_names = [field[0] for field in fields]

buffer = []
for sr in sf.shapeRecords():
   atr = dict(zip(field_names, sr.record))

   geom = sr.shape.__geo_interface__
   buffer.append(dict(type="Feature", geometry=geom, properties=atr)) 

geojson = open("pyshp-demo.geojson", "w")
geojson.write(json.dumps({"type": "FeatureCollection", "features": buffer}, indent=2, ensure_ascii=False))
geojson.close()
